cli Package
===========

:mod:`cli` Package
------------------

.. automodule:: ivy.cli
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`main` Module
------------------

.. automodule:: ivy.cli.main
    :members:
    :undoc-members:
    :show-inheritance:

